@@ -17,17 +17,14 @@ class ConfigInspector:
 
     def _get_fields(self):
         fieldDict = dict()
-        for field in fields(self.config):
-            fieldDict.setdefault(field.name, field)
+        for field in fields(self.config): fieldDict.setdefault(field.name, field)
         return fieldDict
 
     def _get_configClasses(self):
         configClassesDict = dict()
         for k, v in self.config.__dict__.items():
-            if v is None:
-                continue
-            if is_configclass(v):
-                configClassesDict.setdefault(k, v)
+            if v is None: continue
+            if is_configclass(v): configClassesDict.setdefault(k, v)
         return configClassesDict
 
     def is_configClass(self, fieldName):
@@ -37,39 +34,29 @@ class ConfigInspector:
         return self.fields.get(name)
 
     def set(self, name, value=None, help=None):
-        if not hasattr(self.config, name):
-            return
+        if not hasattr(self.config, name): return
         field = self.get_field(name)
-        if field is None:
-            return
-
-        if value is not None:
-            setattr(self.config, name, field.type(value))
-
-        if help is not None and help != '':
-            field.help = help
+        if field is None: return
+        if value is not None: setattr(self.config, name, field.type(value))
+        if help is not None and help != '': field.help = help
 
     def value(self, name):
         getattr(self.config, name)
 
     def help(self, name):
         field = self.get_field(name)
-        if field is not None:
-            return field.help
+        if field is not None: return field.help
         if hasattr(self.config, name):
             attr = getattr(self.config, name)
-            if attr is not None and hasattr(attr, 'help'):
-                return getattr(attr, 'help')
+            if attr is not None and hasattr(attr, 'help'): return getattr(attr, 'help')
         return None
 
 
 class XmlConfiguration:
     def __init__(self, config):
-        if config is None:
-            raise ValueError("target config type can not be none.")
+        if config is None: raise ValueError("target config type can not be none.")
 
-        if type(config) == type:
-            self.config = config()
+        if type(config) == type: self.config = config()
         self.configInspector = ConfigInspector(self.config)
 
     def __set_xml2arg(self, groupInspector, argXml):
@@ -77,12 +64,10 @@ class XmlConfiguration:
         groupInspector.set(argName, argXml['default'], argXml['help'])
 
     def __set_xml2group(self, groupObj, groupXml):
-        if not hasattr(groupXml, 'arg'):
-            return
+        if not hasattr(groupXml, 'arg'): return
         groupInspector = ConfigInspector(groupObj)
         if isinstance(groupXml.arg, list):
-            for arg in groupXml.arg:
-                self.__set_xml2arg(groupInspector, arg)
+            for arg in groupXml.arg: self.__set_xml2arg(groupInspector, arg)
         else:
             self.__set_xml2arg(groupInspector, groupXml.arg)
 
@@ -94,8 +79,7 @@ class XmlConfiguration:
         if groupField is not None:
             self.configInspector.set(groupName, help=groupHelp)
         else:
-            if groupObj is None:
-                return
+            if groupObj is None: return
             setattr(groupObj, 'help', groupHelp)
         self.__set_xml2group(groupObj, groupXml)
 
@@ -107,24 +91,20 @@ class XmlConfiguration:
         :param xml_file:
         :return: configuration object
         """
-        if xml_files is None:
-            return self.config
+        if xml_files is None: return self.config
         for xml_file in xml_files:
             xml = utils.load_xml(xml_file)
 
-            if xml is None:
-                return self.config
+            if xml is None: return self.config
 
             # if has group, set the args in the groups
             if hasattr(xml.configuration, 'group'):
                 if isinstance(xml.configuration.group, list):
-                    for group in xml.configuration.group:
-                        self.__find_set_xml2group(self.config, group)
+                    for group in xml.configuration.group: self.__find_set_xml2group(self.config, group)
                 else:
                     self.__find_set_xml2group(self.config, xml.configuration.group)
             ## set other args
-            if hasattr(xml.configuration, 'arg'):
-                self.__set_xml2group(self.config, xml.configuration)
+            if hasattr(xml.configuration, 'arg'): self.__set_xml2group(self.config, xml.configuration)
 
         return self.config
 
@@ -141,8 +121,7 @@ class ComplexArguments:
 
     def __create_args(self):
         for sub, arg_obj in self._sub_arg_objs.items():
-            if arg_obj is None:
-                continue
+            if arg_obj is None: continue
             parser = self._subparsers.add_parser(sub, help='{} help'.format(sub))
             self._arg_objs[sub] = Arguments(arg_obj, parser, self._grouped)
 
@@ -156,8 +135,7 @@ class ComplexArguments:
     def parse(self, args=None):
         args, _ = self._parser.parse_known_args(args)
         # print("parsed input args:{}".format(str(args)))
-        if not self._arg_objs:
-            return None, None
+        if not self._arg_objs: return None, None
         return args.cmd, self._get_arg_obj(args.cmd, args)
 
 
@@ -173,29 +151,24 @@ class Arguments:
     def __get_type_action(self, field):
         action = 'store'
         if field.type == bool:
-            if field.default:
-                return 'store_false'
-            else:
-                return 'store_true'
+            if field.default: return 'store_false'
+            else: return 'store_true'
         return action
 
     def __get_group(self, groupName, help=''):
         group = self.groups.get(groupName)
-        if group is not None:
-            return group
+        if group is not None: return group
         group = self.parser.add_argument_group(groupName, help)
         self.groups.setdefault(groupName, group)
         return group
 
     def _arg(self, field, v, parser, group=None):
         name = field.name
-        if group is not None:
-            name = group + '.' + name
+        if group is not None: name = group + '.' + name
 
         action = self.__get_type_action(field)
         required = True
-        if v is None:
-            required = False
+        if v is None: required = False
         name = name.replace('_', '-')
         parser.add_argument('--' + name,
                             default=v,
@@ -212,11 +185,8 @@ class Arguments:
 
         for k, v in configInspector.configClasses.items():
             parser = self.__get_group(k, configInspector.help(k)) if self.with_group_prefix else self.parser
-
-            if self.with_group_prefix:
-                self._arg_obj(ConfigInspector(v), parser, k)
-            else:
-                self._arg_obj(ConfigInspector(v), parser, k)
+            group_name = k if self.with_group_prefix else None
+            self._arg_obj(ConfigInspector(v), parser, group_name)
 
         return self
 
